# coding=utf-8
import urllib.request
import random
import re
useragents=["AdsBot-Google ( http://www.google.com/adsbot.html)",
			"Avant Browser/1.2.789rel1 (http://www.avantbrowser.com)"
]

def proxyget(url):
	try:
		req = urllib.request.Request(url) 
		req.add_header("User-Agent", random.choice(useragents)) 
		sourcecode = urllib.request.urlopen(req, timeout = 10) 
		for line in sourcecode :
				ip = re.findall("(?:[\d]{1,3})\.(?:[\d]{1,3})\.(?:[\d]{1,3})\.(?:[\d]{1,3}):(?:[\d]{1,5})", str(line)) 
				ipf = list(filter(lambda x: x if not x.startswith("0.") else None, ip)) 
				if ipf: 
					for x in ipf:						
						out_file = open("proxy.txt","a")
						while True:
							out_file.write(x+"\n") 
							out_file.close()
							break 
	except:
		print("\nAn error occurred, skipping to the next website.")



def proxylist(): 
	global proxies
	print ("\nChecking for duplicates...")
	proxies = open("proxy.txt").readlines() 
	proxiesp = []
	for i in proxies:
		if i not in proxiesp:
			proxiesp.append(i) 
	filepr = open("proxy.txt", "w") 
	filepr.close()
	filepr = open("proxy.txt", "a") 
	for i in proxiesp:
		filepr.write(i)
	print("Current IPs in proxylist: %s" % (len(open("proxy.txt").readlines())))
	print ("\nProxylist Updated!\n")

def get_proxy():
	out_file = open("proxy.txt","w") 
	out_file.close()
	foxtools = ['http://api.foxtools.ru/v2/Proxy.txt?page=%d' % n for n in range(1, 6)]
	for position, url in enumerate(foxtools):
		proxyget(url)
	print("Current IPs in proxylist: %s" % (len(open("proxy.txt").readlines())))


# coding=utf-8
import requests
import re
from ytlv.proxy_stell import get_proxy
class islive():
    def random_line(fname):
        lines = open(fname).read().splitlines()
        return(lines)




#--------------------------------------------------------------------正常--------------------------------------------------------------------    
    def ytid(self,chid):
        link=(f"https://www.youtube.com/channel/{chid}/live")
        
        try:
            r = requests.get(link)
            if  re.search(r'"isLive":true', r.text) is None:                
                data=[{"link":link,"status":"NONE","title":"NONE"}]  
                return(data)
            else:
                try:
                    title=re.findall(r'title="(.*?)"',r.text)
                    for i in title:
                        if i !="YouTube":
                            title=i
                            break
                except:
                    title="NONE"
                try:
                    status=re.search(r'"status":"(.*?)"',r.text).group(1)
                    if status=="LIVE_STREAM_OFFLINE":
                        status="LIVE_OFFLINE"
                except:
                    status="NONE"
                data=[{"link":link,"status":status,"title":title}]  
                return(data)
        except:
            data=[{"link":link,"status":"ERROR","title":"ERROR"}]  
            return(data)
    def ytlk(self,chid):
        link=f"{chid}/live"
        
        try:
            r = requests.get(link)
            if  re.search(r'"isLive":true', r.text) is None:                
                data=[{"link":link,"status":"NONE","title":"NONE"}]  
                return(data)
            else:
                try:
                    title=re.findall(r'title="(.*?)"',r.text)
                    for i in title:
                        if i !="YouTube":
                            title=i
                            break
                except:
                    title="NONE"
                try:
                    status=re.search(r'"status":"(.*?)"',r.text).group(1)

                    if status=="LIVE_STREAM_OFFLINE":
                        status="LIVE_OFFLINE"
                except:
                    status="NONE"
                data=[{"link":link,"status":status,"title":title}]  
                return(data)
        except:
            data=[{"link":link,"status":"ERROR","title":"ERROR"}]  
            return(data)
#--------------------------------------------------------------------正常--------------------------------------------------------------------  
#--------------------------------------------------------------------天使--------------------------------------------------------------------           
    def uto(self,chid):
        link=chid        
        try:
            r = requests.get(link)
            if  re.search(r'"isLive":true', r.text) is None:                
                data=[{"link":link,"status":"NONE","title":"NONE"}]  
                return(data)
            else:
                try:
                    title=re.findall(r'title="(.*?)"',r.text)
                    for i in title:
                        if i !="YouTube":
                            title=i
                            break
                except:
                    title="NONE"
                try:
                    status=re.search(r'"status":"(.*?)"',r.text).group(1)

                    if status=="LIVE_STREAM_OFFLINE":
                        status="LIVE_OFFLINE"
                except:
                    status="NONE"
                data=[{"link":link,"status":status,"title":title}]  
                return(data)


        except:
            data=[{"link":link,"status":"ERROR","title":"ERROR"}]  
            return(data)
#--------------------------------------------------------------------天使--------------------------------------------------------------------  
#--------------------------------------------------------------------代理--------------------------------------------------------------------  
    def prytid(self,chid):
        link=(f"https://www.youtube.com/channel/{chid}/live")
        proxy = random_line('proxy.txt')
        proxies = {
        'http': 'http://' + proxy,
        'https': 'https://' + proxy,
         }

        try:
            r = requests.get(link,proxies=proxies)
            if  re.search(r'"isLive":true', r.text) is None:                
                data=[{"link":link,"status":"NONE","title":"NONE"}]  
                return(data)
            else:
                try:
                    title=re.findall(r'title="(.*?)"',r.text)
                    for i in title:
                        if i !="YouTube":
                            title=i
                            break
                except:
                    title="NONE"
                try:
                    status=re.search(r'"status":"(.*?)"',r.text).group(1)
                    if status=="LIVE_STREAM_OFFLINE":
                        status="LIVE_OFFLINE"
                except:
                    status="NONE"
                data=[{"link":link,"status":status,"title":title}]  
                return(data)
        except:
            data=[{"link":link,"status":"ERROR","title":"ERROR"}]  
            return(data)
    def prytlk(self,chid):
        link=f"{chid}/live"
        proxy = random_line('proxy.txt')
        proxies = {
        'http': 'http://' + proxy,
        'https': 'https://' + proxy,
         }

        try:
            r = requests.get(link,proxies=proxies)
            if  re.search(r'"isLive":true', r.text) is None:                
                data=[{"link":link,"status":"NONE","title":"NONE"}]  
                return(data)
            else:
                try:
                    title=re.findall(r'title="(.*?)"',r.text)
                    for i in title:
                        if i !="YouTube":
                            title=i
                            break
                except:
                    title="NONE"
                try:
                    status=re.search(r'"status":"(.*?)"',r.text).group(1)

                    if status=="LIVE_STREAM_OFFLINE":
                        status="LIVE_OFFLINE"
                except:
                    status="NONE"
                data=[{"link":link,"status":status,"title":title}]  
                return(data)
        except:
            data=[{"link":link,"status":"ERROR","title":"ERROR"}]  
            return(data)
    def lvgetproxy(self):
        get_proxy()
#--------------------------------------------------------------------代理--------------------------------------------------------------------  


import setuptools
with open("lol", "r") as lo:
    long_description = lo.read()

setuptools.setup(
     name='youtube_lv',  
     version='0.2.2',
     author="phillychi3",
     author_email="phillychi3@gmail.com",
     description="check youtuber live status",
     long_description=long_description,
     url="https://github.com/phillychi3/youtube_lv",
     py_modules=["youtube","youtuber","status","live"],
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: Apache Software License",
         "Operating System :: OS Independent",
     ]
    
 )